==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/CertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.CertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property pem PEM formatted public key.
 */
public data class CertificateArgs(
    public val pem: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.CertificateArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.CertificateArgs =
        com.pulumi.azurenative.documentdb.inputs.CertificateArgs.builder()
            .pem(pem?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CertificateArgs].
 */
@PulumiTagMarker
public class CertificateArgsBuilder internal constructor() {
    private var pem: Output<String>? = null

    /**
     * @param value PEM formatted public key.
     */
    @JvmName("rqxyleskwyuyiljt")
    public suspend fun pem(`value`: Output<String>) {
        this.pem = value
    }

    /**
     * @param value PEM formatted public key.
     */
    @JvmName("imdrcrropscgtkrp")
    public suspend fun pem(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pem = mapped
    }

    internal fun build(): CertificateArgs = CertificateArgs(
        pem = pem,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/CertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.CertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property pem PEM formatted public key.
 */
public data class CertificateArgs(
    public val pem: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.CertificateArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.CertificateArgs =
        com.pulumi.azurenative.documentdb.inputs.CertificateArgs.builder()
            .pem(pem?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CertificateArgs].
 */
@PulumiTagMarker
public class CertificateArgsBuilder internal constructor() {
    private var pem: Output<String>? = null

    /**
     * @param value PEM formatted public key.
     */
    @JvmName("gdkkrtojymtqsvfv")
    public suspend fun pem(`value`: Output<String>) {
        this.pem = value
    }

    /**
     * @param value PEM formatted public key.
     */
    @JvmName("gxrattyfrlqjctyn")
    public suspend fun pem(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pem = mapped
    }

    internal fun build(): CertificateArgs = CertificateArgs(
        pem = pem,
    )
}
